@@ -9,18 +9,19 @@
 
 # Overall control of AEC
 
-def run(file, username, password, overwrite=False, AOT = 'MERRA2', n_photon = 100_000, AOT_offset = 0.0):
+def run(file, username, password, overwrite=False, AOT='MERRA2', n_photon=100_000, AOT_offset=0.0, n_jobs=100):
     '''Run adjacency-effect correction on satellite files. See 'Introduction - Adjacency-Effect Correction' for detailed instructions.
     
     Arguments:
         
-    * ``file`` -- String. Path to satellite files. For L8/S2: provide path to the folder. For PRISMA: provide ACOLITE L1R file. 
+    * ``file`` -- String. Path to satellite files. For L8/S2: provide path to the folder. For PRISMA: provide ACOLITE L1R file. SAFE.zip for S2 is supported: when doing so it is recommended to set ``overwrite`` as True to save space. 
     * ``username`` -- String. Username of EarthData account.
     * ``password`` -- String. Password of EarthData account.
     * ``overwrite`` -- Boolean. If overwrite the existing files. The default is False and it creates a folder in the same directory that starts with AEC in the name
-    * ``AOT`` -- Float. AOT at 550nm. 'NIR': calculate in T-Mart. 'MERRA2': use ancillary data (default).
+    * ``AOT`` -- 'MERRA2': use ancillary data (default). Float: AOT at 550nm. 'NIR': calculate in T-Mart by finding dark pixels in NIR when considering the AE. 
     * ``n_photon`` -- Int. Number of photons in each T-Mart run, 100_000 is recommended for accurate results.
     * ``AOT_offset`` -- Float. Value added to AOT at 550nm. If resulted AOT is negative, it will be corrected to 0.
+    * ``n_jobs`` -- Int. Number of jobs in Python multiprocessing. One CPU core processes one job at a time. n_photon is evenly distributed across the jobs.
 
     Example usage::
         
@@ -29,7 +30,7 @@ def run(file, username, password, overwrite=False, AOT = 'MERRA2', n_photon = 10
         username = 'abcdef'
         password = '123456'
         
-        ### Multiprocessing needs to be wrapped in 'if __name__ == "__main__":' for Windows systems, this is optional for Mac OS
+        # T-Mart uses multiprocessing, which needs to be wrapped in 'if __name__ == "__main__":' for Windows users
         if __name__ == "__main__":
             tmart.AEC.run(file, username, password)
 
@@ -37,20 +38,13 @@ def run(file, username, password, overwrite=False, AOT = 'MERRA2', n_photon = 10
     
     import tmart
     import sys, os
+    
     import time
     from importlib.metadata import version
     
-    
-    # Identify if directory or file, for S2/L8
-    if os.path.isdir(file):
-        file_is_dir = True
-    # For ACOLITE L1R files, currently supports PRISMA data only 
-    elif os.path.isfile(file) and file[-6:]=='L1R.nc': 
-        file_is_dir = False
-    else: 
-        sys.exit('File or folder cannot be identified: {}'.format(file))
-    
-    home_folder = os.path.dirname(file) # where ancillary file and printed info are stored 
+    # Identify directories and files 
+    file, file_is_dir = tmart.AEC.identify_input(file)
+    home_folder = os.path.dirname(file) # where ancillary file and printed info are stored, default: the dir of the file
     basename = os.path.basename(file)
     basename_before_period = basename.split('.')[0]
     
@@ -64,8 +58,8 @@ def run(file, username, password, overwrite=False, AOT = 'MERRA2', n_photon = 10
             # make the copy 
             print('\nCopying from ' + str(file) + ' to ' + str(file_new) + '... \n')
             if file_is_dir: 
-                from distutils.dir_util import copy_tree
-                copy_tree(file, file_new)
+                from shutil import copytree
+                copytree(file, file_new)
             else:
                 from shutil import copy
                 copy(file, file_new)
@@ -106,14 +100,13 @@ def run(file, username, password, overwrite=False, AOT = 'MERRA2', n_photon = 10
     
     # S2/L89
     if file_is_dir: 
-        tmart_out = tmart.AEC.run_regular(file, username, password, AOT, AOT_offset, n_photon, AEC_record, basename_before_period)
+        tmart_out = tmart.AEC.run_regular(file, username, password, AOT, AOT_offset, n_photon, AEC_record, basename_before_period, n_jobs)
     # ACOLITE L1R 
     else:
-        tmart_out = tmart.AEC.run_acoliteL1R(file, username, password, AOT, AOT_offset, n_photon, AEC_record, basename_before_period)
+        tmart_out = tmart.AEC.run_acoliteL1R(file, username, password, AOT, AOT_offset, n_photon, AEC_record, basename_before_period, n_jobs)
     
     # Stop logging 
     sys.stdout = orig_stdout
 
     return tmart_out
-    
     
\ No newline at end of file
