@@ -7,17 +7,11 @@
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 
-
-
 from .Surface import Surface, SpectralSurface
 from .Atmosphere import Atmosphere
-
-from .Tmart import Tmart
-
+from .tmart import Tmart
 from .tm_calcref import calc_ref 
 from .tm_geometry import dirP_to_coord
 
 from tmart import AEC
 from tmart import surface_rho
-
-
